==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=pl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'wyłącznie do przyszłych artykułów (brak działania na bazie danych).',
	'bouton_radio_articles_tous' => 'do wszystkich artykułów bez wyjątków.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'do wszystkich artykułów z wyjątkiem tych z nieczynnym forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Obowiązkowa rejestracja (użytkownicy muszą się zapisać przez podanie adresu e-mail aby mieć możliwość zamieszczania postów).',
	'bouton_radio_moderation_priori' => 'Uprzednia moderacja (
 posty będą się ukazywać dopiero po ich zatwierdzeniu przez
 administratorów).', # MODIF
	'bouton_radio_modere_abonnement' => 'na abonament',
	'bouton_radio_modere_posteriori' => 'moderacja a posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderacja a priori', # MODIF
	'bouton_radio_publication_immediate' => 'Natychmiastowa publikacja wiadomości
 (posty będą się ukazywać w momencie ich wysłania, administratorzy mogą
 je później usunąć).',

	// F
	'form_pet_message_commentaire' => 'Jakieś wiadomości lub komentarze?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Nie masz już dostępu do tego forum.',
	'forum_attention_dix_caracteres' => '<b>Uwaga!</b> Twoja wiadomość powinna mieć conajmniej 10 znaków.',
	'forum_attention_trois_caracteres' => '<b>Uwaga!</b> Twój temat powinien mieć conajmniej 3 znaki.',
	'forum_attention_trop_caracteres' => '<b>Uwaga !</b> Twoja wiadomość jest za długa(@compte@ znaków) : aby mogła zostać przyjęta nie może przekraczać @max@ znaków.', # MODIF
	'forum_avez_selectionne' => 'Wybrałeś:',
	'forum_cliquer_retour' => 'Kliknij <a href=\'@retour_forum@\'>tutaj</a> aby kontynuować.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'To forum jest moderowane : Twój wpis ukaże się dopiero po weryfikacji przez administratora strony.', # MODIF
	'forum_lien_hyper' => '<b>Link</b> (opcjonalny)', # MODIF
	'forum_message_definitif' => 'Wiadomość końcowa: wyślij na stronę',
	'forum_message_trop_long' => 'Twoja wiadomość jest za długa. Maksymalna długość to 20000 znaków.', # MODIF
	'forum_ne_repondez_pas' => 'Nie odpowiadaj na tego maila, lecz na forum, pod następującym adresem:', # MODIF
	'forum_page_url' => '(Jeśli twoja wiadomość odnosi się jakiegoś artykuły opublikowanego w internecie, wpisz poniżej tytuł tej strony oraz jej adres).',
	'forum_poste_par' => 'Wiadomość na temat twojego artykułu napisana przez@parauteur@.', # MODIF
	'forum_qui_etes_vous' => '<b>Kim jesteś?</b> (nieobowiązkowe)', # MODIF
	'forum_texte' => 'Tekst Twojej wiadomości:', # MODIF
	'forum_titre' => 'Temat:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Zatwierdź ten wybór',
	'forum_voir_avant' => 'Podgląd wiadomości przed umieszczeniem na forum', # MODIF
	'forum_votre_email' => 'Twój adres e-mail:', # MODIF
	'forum_votre_nom' => 'Twoje imię (lub alias):', # MODIF
	'forum_vous_enregistrer' => 'Aby uczestniczyć w
  tym forum - musisz się zarejestrować Dziękuję
  za wprowadzenie loginu
  o który prosimy. Jeśli nie jesteś jeszcze zarejstrowany, musisz',
	'forum_vous_inscrire' => 'się zarejestrować.',

	// I
	'icone_poster_message' => 'Napisz wiadomość',
	'icone_suivi_forum' => 'Śledź wątek forum publicznego: @nb_forums@',
	'icone_suivi_forums' => 'Zarządzanie forum',
	'icone_supprimer_message' => 'Usuń tę wiadomość',
	'icone_valider_message' => 'Zatwierdź tę wiadomość',
	'info_activer_forum_public' => '<i>Aby aktywować forum publiczne, wybierz domyślny sposób moderacji</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Wybierze ten sposób moderowania:',
	'info_desactiver_forum_public' => 'Wyłącz możliwość korzystania z forum
 publicznego. Forum publiczne będzie można w pewnych przypadkach aktywować
 dołączając je do określonych artykułów ; wyłączenie będzie dotyczyło przede wszystkim działów i skrótów itd.',
	'info_envoi_forum' => 'Wysyłka forum do autorów artykułów',
	'info_fonctionnement_forum' => 'Funkcjonowanie forum :',
	'info_gauche_suivi_forum_2' => 'Strona  <i>archiwum forum</i> jest narzędziem administracji stroną (a nie miejscem dyskusji czy redagowania). Wyświetla ona wszystkie komentarze forum z całego serwisu, zarówno te ze stron publicznych i strefy prywatnej i pozwala na zarządzanie tymi komentarzami.', # MODIF
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'są',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'jest',
	'info_liens_syndiques_7' => 'w trakcie zatwierdzania.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Domyślny tryb funkcjonowania forum publicznego',
	'info_option_email' => 'Kiedy odwiedzający stronę zostawią na forum wiadomość
  związaną z artykułem, autorzy artykułu mogą zostać
  poinformowani o tym przez e-mail. Czy chcesz zastosować tę opcję?', # MODIF
	'info_pas_de_forum' => 'brak forum',
	'item_activer_forum_administrateur' => 'Aktywuj forum administratorów',
	'item_desactiver_forum_administrateur' => 'Wyłącz forum administratorów',

	// L
	'lien_reponse_article' => 'Odpowiedz na ten artykuł',
	'lien_reponse_breve_2' => 'Odpowiedz na ten news',
	'lien_reponse_rubrique' => 'Odpowiedz w tym dziale',
	'lien_reponse_site_reference' => 'Odwołanie się do zlinkowanej strony :', # MODIF

	// O
	'onglet_messages_internes' => 'Wiadomości wewnętrzne',
	'onglet_messages_publics' => 'Wiadomości publiczne',
	'onglet_messages_vide' => 'Wiadomości bez tekstu',

	// R
	'repondre_message' => 'Skomentuj wiadomość',

	// S
	'statut_original' => 'oryginalny',

	// T
	'titre_cadre_forum_administrateur' => 'Prywatne forum administratorów',
	'titre_cadre_forum_interne' => 'Forum wewnętrzne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Archiwum forum',
	'titre_page_forum_suivi' => 'Archiwum forum'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=pl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'wyłącznie do przyszłych artykułów (brak działania na bazie danych).',
	'bouton_radio_articles_tous' => 'do wszystkich artykułów bez wyjątków.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'do wszystkich artykułów z wyjątkiem tych z nieczynnym forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Obowiązkowa rejestracja (użytkownicy muszą się zapisać przez podanie adresu e-mail aby mieć możliwość zamieszczania postów).',
	'bouton_radio_moderation_priori' => 'Uprzednia moderacja (
 posty będą się ukazywać dopiero po ich zatwierdzeniu przez
 administratorów).', # MODIF
	'bouton_radio_modere_abonnement' => 'na abonament',
	'bouton_radio_modere_posteriori' => 'moderacja a posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderacja a priori', # MODIF
	'bouton_radio_publication_immediate' => 'Natychmiastowa publikacja wiadomości
 (posty będą się ukazywać w momencie ich wysłania, administratorzy mogą
 je później usunąć).',

	// F
	'form_pet_message_commentaire' => 'Jakieś wiadomości lub komentarze?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Nie masz już dostępu do tego forum.',
	'forum_attention_dix_caracteres' => '<b>Uwaga!</b> Twoja wiadomość powinna mieć conajmniej 10 znaków.',
	'forum_attention_trois_caracteres' => '<b>Uwaga!</b> Twój temat powinien mieć conajmniej 3 znaki.',
	'forum_attention_trop_caracteres' => '<b>Uwaga !</b> Twoja wiadomość jest za długa(@compte@ znaków) : aby mogła zostać przyjęta nie może przekraczać @max@ znaków.', # MODIF
	'forum_avez_selectionne' => 'Wybrałeś:',
	'forum_cliquer_retour' => 'Kliknij <a href=\'@retour_forum@\'>tutaj</a> aby kontynuować.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'To forum jest moderowane : Twój wpis ukaże się dopiero po weryfikacji przez administratora strony.', # MODIF
	'forum_lien_hyper' => '<b>Link</b> (opcjonalny)', # MODIF
	'forum_message_definitif' => 'Wiadomość końcowa: wyślij na stronę',
	'forum_message_trop_long' => 'Twoja wiadomość jest za długa. Maksymalna długość to 20000 znaków.', # MODIF
	'forum_ne_repondez_pas' => 'Nie odpowiadaj na tego maila, lecz na forum, pod następującym adresem:', # MODIF
	'forum_page_url' => '(Jeśli twoja wiadomość odnosi się jakiegoś artykuły opublikowanego w internecie, wpisz poniżej tytuł tej strony oraz jej adres).',
	'forum_poste_par' => 'Wiadomość na temat twojego artykułu napisana przez@parauteur@.', # MODIF
	'forum_qui_etes_vous' => '<b>Kim jesteś?</b> (nieobowiązkowe)', # MODIF
	'forum_texte' => 'Tekst Twojej wiadomości:', # MODIF
	'forum_titre' => 'Temat:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Zatwierdź ten wybór',
	'forum_voir_avant' => 'Podgląd wiadomości przed umieszczeniem na forum', # MODIF
	'forum_votre_email' => 'Twój adres e-mail:', # MODIF
	'forum_votre_nom' => 'Twoje imię (lub alias):', # MODIF
	'forum_vous_enregistrer' => 'Aby uczestniczyć w
  tym forum - musisz się zarejestrować Dziękuję
  za wprowadzenie loginu
  o który prosimy. Jeśli nie jesteś jeszcze zarejstrowany, musisz',
	'forum_vous_inscrire' => 'się zarejestrować.',

	// I
	'icone_poster_message' => 'Napisz wiadomość',
	'icone_suivi_forum' => 'Śledź wątek forum publicznego: @nb_forums@',
	'icone_suivi_forums' => 'Zarządzanie forum',
	'icone_supprimer_message' => 'Usuń tę wiadomość',
	'icone_valider_message' => 'Zatwierdź tę wiadomość',
	'info_activer_forum_public' => '<i>Aby aktywować forum publiczne, wybierz domyślny sposób moderacji</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Wybierze ten sposób moderowania:',
	'info_desactiver_forum_public' => 'Wyłącz możliwość korzystania z forum
 publicznego. Forum publiczne będzie można w pewnych przypadkach aktywować
 dołączając je do określonych artykułów ; wyłączenie będzie dotyczyło przede wszystkim działów i skrótów itd.',
	'info_envoi_forum' => 'Wysyłka forum do autorów artykułów',
	'info_fonctionnement_forum' => 'Funkcjonowanie forum :',
	'info_gauche_suivi_forum_2' => 'Strona  <i>archiwum forum</i> jest narzędziem administracji stroną (a nie miejscem dyskusji czy redagowania). Wyświetla ona wszystkie komentarze forum z całego serwisu, zarówno te ze stron publicznych i strefy prywatnej i pozwala na zarządzanie tymi komentarzami.', # MODIF
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'są',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'jest',
	'info_liens_syndiques_7' => 'w trakcie zatwierdzania.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Domyślny tryb funkcjonowania forum publicznego',
	'info_option_email' => 'Kiedy odwiedzający stronę zostawią na forum wiadomość
  związaną z artykułem, autorzy artykułu mogą zostać
  poinformowani o tym przez e-mail. Czy chcesz zastosować tę opcję?', # MODIF
	'info_pas_de_forum' => 'brak forum',
	'item_activer_forum_administrateur' => 'Aktywuj forum administratorów',
	'item_desactiver_forum_administrateur' => 'Wyłącz forum administratorów',

	// L
	'lien_reponse_article' => 'Odpowiedz na ten artykuł',
	'lien_reponse_breve_2' => 'Odpowiedz na ten news',
	'lien_reponse_rubrique' => 'Odpowiedz w tym dziale',
	'lien_reponse_site_reference' => 'Odwołanie się do zlinkowanej strony :', # MODIF

	// O
	'onglet_messages_internes' => 'Wiadomości wewnętrzne',
	'onglet_messages_publics' => 'Wiadomości publiczne',
	'onglet_messages_vide' => 'Wiadomości bez tekstu',

	// R
	'repondre_message' => 'Skomentuj wiadomość',

	// S
	'statut_original' => 'oryginalny',

	// T
	'titre_cadre_forum_administrateur' => 'Prywatne forum administratorów',
	'titre_cadre_forum_interne' => 'Forum wewnętrzne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Archiwum forum',
	'titre_page_forum_suivi' => 'Archiwum forum',
];
